==> aplus_chat-0.0.9.tar.gz: lib/model/conversation_list_model.dart <==
// To parse this JSON data, do
//
//     final conversationListModel = conversationListModelFromJson(jsonString);

import 'dart:convert';

import 'package:get/get.dart';

ConversationListModel conversationListModelFromJson(str) =>
    ConversationListModel.fromJson(str);

String conversationListModelToJson(ConversationListModel data) =>
    json.encode(data.toJson());

class ConversationListModel {
  ConversationListModel({
    this.messages,
    this.hasMore,
    this.groupData,
  });

  List<Message>? messages;
  bool? hasMore;
  GroupData? groupData;

  factory ConversationListModel.fromJson(Map<String, dynamic> json) =>
      ConversationListModel(
        messages: json["messages"] == null
            ? []
            : List<Message>.from(
                json["messages"]!.map((x) => Message.fromJson(x))),
        hasMore: json["hasMore"],
        groupData: json["groupData"] == null
            ? null
            : GroupData.fromJson(json["groupData"]),
      );

  Map<String, dynamic> toJson() => {
        "messages": messages == null
            ? []
            : List<dynamic>.from(messages!.map((x) => x.toJson())),
        "hasMore": hasMore,
        "groupData": groupData?.toJson(),
      };
}

class GroupData {
  GroupData({
    this.userPermission,
    this.userName,
    this.onlineStatus,
    this.groupName,
    this.imagePath,
  });

  UserPermission? userPermission;
  String? userName;
  bool? onlineStatus;
  String? groupName;
  String? imagePath;

  factory GroupData.fromJson(Map<String, dynamic> json) => GroupData(
        userPermission: json["userPermission"] == null
            ? null
            : UserPermission.fromJson(json["userPermission"]),
        userName: json["userName"],
        onlineStatus: json["onlineStatus"],
        groupName: json["groupName"],
        imagePath: json["imagePath"],
      );

  Map<String, dynamic> toJson() => {
        "userPermission": userPermission?.toJson(),
        "userName": userName,
        "onlineStatus": onlineStatus,
        "groupName": groupName,
        "imagePath": imagePath,
      };
}

class UserPermission {
  UserPermission({
    this.permission,
    this.userId,
  });

  Permission? permission;
  String? userId;

  factory UserPermission.fromJson(Map<String, dynamic> json) => UserPermission(
        permission: json["permission"] == null
            ? null
            : Permission.fromJson(json["permission"]),
        userId: json["userId"],
      );

  Map<String, dynamic> toJson() => {
        "permission": permission?.toJson(),
        "userId": userId,
      };
}

class Permission {
  Permission({
    this.removeMember,
    this.addMember,
    this.clearChat,
    this.deleteChat,
    this.sendMessage,
    this.exitGroup,
    this.deleteMessage,
    this.changeGroupName,
    this.addProfilePicture,
  });

  int? removeMember;
  int? addMember;
  int? clearChat;
  int? deleteChat;
  int? sendMessage;
  int? exitGroup;
  int? deleteMessage;
  int? changeGroupName;
  int? addProfilePicture;

  factory Permission.fromJson(Map<String, dynamic> json) => Permission(
        removeMember: json["removeMember"],
        addMember: json["addMember"],
        clearChat: json["clearChat"],
        deleteChat: json["deleteChat"],
        sendMessage: json["sendMessage"],
        exitGroup: json["exitGroup"],
        deleteMessage: json["deleteMessage"],
        changeGroupName: json["changeGroupName"],
        addProfilePicture: json["addProfilePicture"],
      );

  Map<String, dynamic> toJson() => {
        "removeMember": removeMember,
        "addMember": addMember,
        "clearChat": clearChat,
        "deleteChat": deleteChat,
        "sendMessage": sendMessage,
        "exitGroup": exitGroup,
        "deleteMessage": deleteMessage,
        "changeGroupName": changeGroupName,
        "addProfilePicture": addProfilePicture,
      };
}

Message messagesFromJson(str) => Message.fromJson(str);

class Message {
  Message({
    this.timeMilliSeconds,
    this.sentBy,
    this.type,
    this.msgId,
    this.message,
    this.name,
    this.fileName,
    this.contentType,
    this.senderName,
    this.filePath,
    this.replyUser,
    this.replyMsg,
    this.replyMsgId,
    this.replyUserId,
    this.replyMsgType,
    this.time,
  });

  TimeMilliSeconds? timeMilliSeconds;
  String? sentBy;
  String? type;
  String? msgId;
  String? message;
  String? name;
  String? fileName;
  String? contentType;
  String? senderName;
  String? filePath;
  String? replyUser;
  String? replyMsg;
  String? replyMsgId;
  String? replyUserId;
  String? replyMsgType;
  var fileUploadLoader = false.obs;
  var videoUploader = false.obs;
  // ignore: prefer_typing_uninitialized_variables
  var time;
  var startAnimation = false.obs;
  factory Message.fromJson(Map<String, dynamic> json) => Message(
        timeMilliSeconds: json["timeMilliSeconds"] == null
            ? null
            : TimeMilliSeconds.fromJson(json["timeMilliSeconds"]),
        sentBy: json["sentBy"],
        type: json["type"],
        msgId: json["msgId"],
        message: json["message"],
        name: json["name"],
        fileName: json["fileName"],
        contentType: json["contentType"],
        senderName: json["senderName"],
        filePath: json["filePath"],
        replyUser: json["replyUser"],
        replyMsg: json["replyMsg"],
        replyMsgId: json["replyMsgId"],
        replyUserId: json["replyUserId"],
        replyMsgType: json["replyMsgType"],
        time: json["time"],
      );

  Map<String, dynamic> toJson() => {
        "timeMilliSeconds": timeMilliSeconds?.toJson(),
        "sentBy": sentBy,
        "type": type,
        "msgId": msgId,
        "message": message,
        "name": name,
        "fileName": fileName,
        "contentType": contentType,
        "senderName": senderName,
        "filePath": filePath,
        "replyUser": replyUser,
        "replyMsg": replyMsg,
        "replyMsgId": replyMsgId,
        "replyUserId": replyUserId,
        "replyMsgType": replyMsgType,
        "time": time,
      };
}

class TimeMilliSeconds {
  TimeMilliSeconds({
    this.seconds,
    this.nanoseconds,
  });

  int? seconds;
  int? nanoseconds;

  factory TimeMilliSeconds.fromJson(Map<String, dynamic> json) =>
      TimeMilliSeconds(
        seconds: json["seconds"],
        nanoseconds: json["nanoseconds"],
      );

  Map<String, dynamic> toJson() => {
        "seconds": seconds,
        "nanoseconds": nanoseconds,
      };
}

==> aplus_chat-0.1.2.tar.gz: lib/model/conversation_list_model.dart <==
// To parse this JSON data, do
//
//     final conversationListModel = conversationListModelFromJson(jsonString);

import 'dart:convert';

import 'package:get/get.dart';

ConversationListModel conversationListModelFromJson(str) =>
    ConversationListModel.fromJson(str);

String conversationListModelToJson(ConversationListModel data) =>
    json.encode(data.toJson());

class ConversationListModel {
  ConversationListModel({
    this.messages,
    this.hasMore,
    this.groupData,
  });

  List<Message>? messages;
  bool? hasMore;
  GroupData? groupData;

  factory ConversationListModel.fromJson(Map<String, dynamic> json) =>
      ConversationListModel(
        messages: json["messages"] == null
            ? []
            : List<Message>.from(
                json["messages"]!.map((x) => Message.fromJson(x))),
        hasMore: json["hasMore"],
        groupData: json["groupData"] == null
            ? null
            : GroupData.fromJson(json["groupData"]),
      );

  Map<String, dynamic> toJson() => {
        "messages": messages == null
            ? []
            : List<dynamic>.from(messages!.map((x) => x.toJson())),
        "hasMore": hasMore,
        "groupData": groupData?.toJson(),
      };
}

class GroupData {
  GroupData({
    this.userPermission,
    this.userName,
    this.onlineStatus,
    this.groupName,
    this.imagePath,
  });

  UserPermission? userPermission;
  String? userName;
  bool? onlineStatus;
  String? groupName;
  String? imagePath;

  factory GroupData.fromJson(Map<String, dynamic> json) => GroupData(
        userPermission: json["userPermission"] == null
            ? null
            : UserPermission.fromJson(json["userPermission"]),
        userName: json["userName"],
        onlineStatus: json["onlineStatus"],
        groupName: json["groupName"],
        imagePath: json["imagePath"],
      );

  Map<String, dynamic> toJson() => {
        "userPermission": userPermission?.toJson(),
        "userName": userName,
        "onlineStatus": onlineStatus,
        "groupName": groupName,
        "imagePath": imagePath,
      };
}

class UserPermission {
  UserPermission({
    this.permission,
    this.userId,
  });

  Permission? permission;
  String? userId;

  factory UserPermission.fromJson(Map<String, dynamic> json) => UserPermission(
        permission: json["permission"] == null
            ? null
            : Permission.fromJson(json["permission"]),
        userId: json["userId"],
      );

  Map<String, dynamic> toJson() => {
        "permission": permission?.toJson(),
        "userId": userId,
      };
}

class Permission {
  Permission({
    this.removeMember,
    this.addMember,
    this.clearChat,
    this.deleteChat,
    this.sendMessage,
    this.exitGroup,
    this.deleteMessage,
    this.changeGroupName,
    this.addProfilePicture,
  });

  int? removeMember;
  int? addMember;
  int? clearChat;
  int? deleteChat;
  int? sendMessage;
  int? exitGroup;
  int? deleteMessage;
  int? changeGroupName;
  int? addProfilePicture;

  factory Permission.fromJson(Map<String, dynamic> json) => Permission(
        removeMember: json["removeMember"],
        addMember: json["addMember"],
        clearChat: json["clearChat"],
        deleteChat: json["deleteChat"],
        sendMessage: json["sendMessage"],
        exitGroup: json["exitGroup"],
        deleteMessage: json["deleteMessage"],
        changeGroupName: json["changeGroupName"],
        addProfilePicture: json["addProfilePicture"],
      );

  Map<String, dynamic> toJson() => {
        "removeMember": removeMember,
        "addMember": addMember,
        "clearChat": clearChat,
        "deleteChat": deleteChat,
        "sendMessage": sendMessage,
        "exitGroup": exitGroup,
        "deleteMessage": deleteMessage,
        "changeGroupName": changeGroupName,
        "addProfilePicture": addProfilePicture,
      };
}

Message messagesFromJson(str) => Message.fromJson(str);

class Message {
  Message(
      {this.timeMilliSeconds,
      this.sentBy,
      this.type,
      this.msgId,
      this.message,
      this.name,
      this.fileName,
      this.contentType,
      this.senderName,
      this.filePath,
      this.replyUser,
      this.replyMsg,
      this.replyMsgId,
      this.replyUserId,
      this.replyMsgType,
      this.time,
      this.thumbnailPath});

  TimeMilliSeconds? timeMilliSeconds;
  String? sentBy;
  String? type;
  String? msgId;
  String? message;
  String? name;
  String? fileName;
  String? contentType;
  String? senderName;
  String? filePath;
  String? replyUser;
  String? replyMsg;
  String? replyMsgId;
  String? replyUserId;
  String? replyMsgType;
  String? thumbnailPath;
  var fileUploadLoader = false.obs;
  var videoUploader = false.obs;
  // ignore: prefer_typing_uninitialized_variables
  var time;
  var startAnimation = false.obs;
  factory Message.fromJson(Map<String, dynamic> json) => Message(
        timeMilliSeconds: json["timeMilliSeconds"] == null
            ? null
            : TimeMilliSeconds.fromJson(json["timeMilliSeconds"]),
        sentBy: json["sentBy"],
        type: json["type"],
        msgId: json["msgId"],
        message: json["message"],
        name: json["name"],
        fileName: json["fileName"],
        contentType: json["contentType"],
        senderName: json["senderName"],
        filePath: json["filePath"],
        replyUser: json["replyUser"],
        replyMsg: json["replyMsg"],
        replyMsgId: json["replyMsgId"],
        replyUserId: json["replyUserId"],
        replyMsgType: json["replyMsgType"],
        time: json["time"],
        thumbnailPath: json["thumbnailPath"],
      );

  Map<String, dynamic> toJson() => {
        "timeMilliSeconds": timeMilliSeconds?.toJson(),
        "sentBy": sentBy,
        "type": type,
        "msgId": msgId,
        "message": message,
        "name": name,
        "fileName": fileName,
        "contentType": contentType,
        "senderName": senderName,
        "filePath": filePath,
        "replyUser": replyUser,
        "replyMsg": replyMsg,
        "replyMsgId": replyMsgId,
        "replyUserId": replyUserId,
        "replyMsgType": replyMsgType,
        "time": time,
        "thumbnailPath": thumbnailPath,
      };
}

class TimeMilliSeconds {
  TimeMilliSeconds({
    this.seconds,
    this.nanoseconds,
  });

  int? seconds;
  int? nanoseconds;

  factory TimeMilliSeconds.fromJson(Map<String, dynamic> json) =>
      TimeMilliSeconds(
        seconds: json["seconds"],
        nanoseconds: json["nanoseconds"],
      );

  Map<String, dynamic> toJson() => {
        "seconds": seconds,
        "nanoseconds": nanoseconds,
      };
}
